@@ -1,44 +1,37 @@
 import logging
 import re
-import sys
 from os import environ
-
-import six
-
-try:
-    from unittest.mock import MagicMock
-    from unittest.mock import PropertyMock
-except ImportError:  # python 2
-    from mock import MagicMock
-    from mock import PropertyMock
+from unittest.mock import MagicMock, PropertyMock
 
 import pytest
 from requests import Response
+from requests.adapters import DEFAULT_POOLBLOCK, DEFAULT_POOLSIZE
 
-from qbittorrentapi import APINames
-from qbittorrentapi import Client
-from qbittorrentapi import exceptions
+from qbittorrentapi import APINames, Client, exceptions
 from qbittorrentapi._version_support import v
-from qbittorrentapi.definitions import Dictionary
-from qbittorrentapi.definitions import List
+from qbittorrentapi.definitions import Dictionary, List
+from qbittorrentapi.exceptions import Forbidden403Error
 from qbittorrentapi.request import Request
-from qbittorrentapi.torrents import TorrentDictionary
-from qbittorrentapi.torrents import TorrentInfoList
+from qbittorrentapi.torrents import TorrentDictionary, TorrentInfoList
 from tests.conftest import IS_QBT_DEV
-from tests.conftest import mkpath
+from tests.utils import mkpath
 
 
 def test_method_name(client, app_version):
-    assert app_version == client._get("app", "version", response_class=six.text_type)
+    assert app_version == client._get("app", "version", response_class=str)
     assert app_version == client._get(
-        APINames.Application, "version", response_class=six.text_type
+        APINames.Application,
+        "version",
+        response_class=str,
     )
 
 
 def test_log_in():
     client_good = Client(VERIFY_WEBUI_CERTIFICATE=False)
     client_bad = Client(
-        username="asdf", password="asdfasdf", VERIFY_WEBUI_CERTIFICATE=False
+        username="asdf",
+        password="asdfasdf",
+        VERIFY_WEBUI_CERTIFICATE=False,
     )
 
     client_good.auth_log_out()
@@ -57,7 +50,9 @@ def test_log_in():
 def test_log_in_via_auth():
     client_good = Client(VERIFY_WEBUI_CERTIFICATE=False)
     client_bad = Client(
-        username="asdf", password="asdfasdf", VERIFY_WEBUI_CERTIFICATE=False
+        username="asdf",
+        password="asdfasdf",
+        VERIFY_WEBUI_CERTIFICATE=False,
     )
 
     assert (
@@ -71,6 +66,23 @@ def test_log_in_via_auth():
         client_bad.auth_log_in(username="asdf", password="asdfasdf")
 
 
+def test_forbidden_when_banned(client, monkeypatch):
+    monkeypatch.setattr(
+        client,
+        "_request_manager",
+        MagicMock(
+            side_effect=Forbidden403Error,
+            spec=client._request_manager,
+        ),
+    )
+
+    with pytest.raises(Forbidden403Error):
+        client.auth.log_in()
+
+    with pytest.raises(Forbidden403Error):
+        _ = client.app.version
+
+
 @pytest.mark.parametrize(
     "hostname",
     (
@@ -86,11 +98,13 @@ def test_log_in_via_auth():
 )
 def test_hostname_format(app_version, hostname):
     client = Client(
-        host=hostname, VERIFY_WEBUI_CERTIFICATE=False, REQUESTS_ARGS={"timeout": 1}
+        host=hostname,
+        VERIFY_WEBUI_CERTIFICATE=False,
+        REQUESTS_ARGS={"timeout": 1},
     )
     assert client.app.version == app_version
     # ensure the base URL is always normalized
-    assert re.match(r"(http|https)://localhost:8080/", client._API_BASE_URL)
+    assert re.match(r"(http|https)://localhost:8080/", client._url._base_url)
 
 
 @pytest.mark.parametrize(
@@ -106,7 +120,7 @@ def test_hostname_user_base_path(hostname):
     with pytest.raises(exceptions.APIConnectionError):
         _ = client.app.version
     # ensure user provided base paths are preserved
-    assert re.match(r"(http|https)://localhost:8080/qbt/", client._API_BASE_URL)
+    assert re.match(r"(http|https)://localhost:8080/qbt/", client._url._base_url)
 
 
 def test_port_from_host(app_version):
@@ -119,75 +133,75 @@ def _enable_disable_https(client, use_https):
     if use_https:
         client.app.preferences = {
             "use_https": True,
-            "web_ui_https_cert_path": mkpath("/tmp", "resources", "server.crt"),
-            "web_ui_https_key_path": mkpath("/tmp", "resources", "server.key"),
+            "web_ui_https_cert_path": mkpath("/tmp", "_resources", "server.crt"),
+            "web_ui_https_key_path": mkpath("/tmp", "_resources", "server.key"),
         }
     else:
         client.app.preferences = {"use_https": False}
 
 
+@pytest.mark.skipif_before_api_version("2.2.1")
 @pytest.mark.parametrize("use_https", (True, False))
-def test_force_user_scheme(client, app_version, api_version, use_https):
-    if v(api_version) >= v("2.2.1"):
-        default_host = environ["QBITTORRENTAPI_HOST"]
+def test_force_user_scheme(client, app_version, use_https):
+    default_host = environ["QBITTORRENTAPI_HOST"]
 
-        _enable_disable_https(client, use_https)
+    _enable_disable_https(client, use_https)
 
-        client = Client(
-            host="http://" + default_host,
-            VERIFY_WEBUI_CERTIFICATE=False,
-            FORCE_SCHEME_FROM_HOST=True,
-            REQUESTS_ARGS={"timeout": 3},
-        )
-        if use_https:
-            with pytest.raises(exceptions.APIConnectionError):
-                assert client.app.version == app_version
-        else:
-            assert client.app.version == app_version
-        assert client._API_BASE_URL.startswith("http://")
-
-        client = Client(
-            host=default_host,
-            VERIFY_WEBUI_CERTIFICATE=False,
-            FORCE_SCHEME_FROM_HOST=True,
-            REQUESTS_ARGS={"timeout": 3},
-        )
-        assert client.app.version == app_version
-        if use_https:
-            assert client._API_BASE_URL.startswith("https://")
-        else:
-            assert client._API_BASE_URL.startswith("http://")
-
-        client = Client(
-            host="https://" + default_host,
-            VERIFY_WEBUI_CERTIFICATE=False,
-            FORCE_SCHEME_FROM_HOST=True,
-            REQUESTS_ARGS={"timeout": 3},
-        )
-        if not use_https:
-            with pytest.raises(exceptions.APIConnectionError):
-                assert client.app.version == app_version
-        else:
-            assert client.app.version == app_version
-        assert client._API_BASE_URL.startswith("https://")
-
-
-@pytest.mark.parametrize("scheme", ("http://", "https://"))
-def test_both_https_http_not_working(client, app_version, api_version, scheme):
-    if v(api_version) >= v("2.2.1"):
-        default_host = environ["QBITTORRENTAPI_HOST"]
-        _enable_disable_https(client, use_https=True)
-
-        # rerun with verify=True
-        test_client = Client(
-            host=scheme + default_host,
-            REQUESTS_ARGS={"timeout": 3},
-        )
+    client = Client(
+        host="http://" + default_host,
+        VERIFY_WEBUI_CERTIFICATE=False,
+        FORCE_SCHEME_FROM_HOST=True,
+        REQUESTS_ARGS={"timeout": 3},
+    )
+    if use_https:
         with pytest.raises(exceptions.APIConnectionError):
-            assert test_client.app.version == app_version
-        assert test_client._API_BASE_URL.startswith("https://")
+            assert client.app.version == app_version
+    else:
+        assert client.app.version == app_version
+    assert client._url._base_url.startswith("http://")
 
-        _enable_disable_https(client, use_https=False)
+    client = Client(
+        host=default_host,
+        VERIFY_WEBUI_CERTIFICATE=False,
+        FORCE_SCHEME_FROM_HOST=True,
+        REQUESTS_ARGS={"timeout": 3},
+    )
+    assert client.app.version == app_version
+    if use_https:
+        assert client._url._base_url.startswith("https://")
+    else:
+        assert client._url._base_url.startswith("http://")
+
+    client = Client(
+        host="https://" + default_host,
+        VERIFY_WEBUI_CERTIFICATE=False,
+        FORCE_SCHEME_FROM_HOST=True,
+        REQUESTS_ARGS={"timeout": 3},
+    )
+    if not use_https:
+        with pytest.raises(exceptions.APIConnectionError):
+            assert client.app.version == app_version
+    else:
+        assert client.app.version == app_version
+    assert client._url._base_url.startswith("https://")
+
+
+@pytest.mark.skipif_before_api_version("2.2.1")
+@pytest.mark.parametrize("scheme", ("http://", "https://"))
+def test_both_https_http_not_working(client, app_version, scheme):
+    default_host = environ["QBITTORRENTAPI_HOST"]
+    _enable_disable_https(client, use_https=True)
+
+    # rerun with verify=True
+    test_client = Client(
+        host=scheme + default_host,
+        REQUESTS_ARGS={"timeout": 3},
+    )
+    with pytest.raises(exceptions.APIConnectionError):
+        assert test_client.app.version == app_version
+    assert test_client._url._base_url.startswith("https://")
+
+    _enable_disable_https(client, use_https=False)
 
 
 def test_legacy_env_vars():
@@ -244,12 +258,12 @@ def test_log_out(client):
     client.auth_log_out()
     with pytest.raises(exceptions.Forbidden403Error):
         # cannot call client.app.version directly since it will auto log back in
-        client._get(APINames.Application, "version")
+        client._request_manager("get", APINames.Application, "version")
     client.auth_log_in()
     client.auth.log_out()
     with pytest.raises(exceptions.Forbidden403Error):
         # cannot call client.app.version directly since it will auto log back in
-        client._get(APINames.Application, "version")
+        client._request_manager("get", APINames.Application, "version")
     client.auth_log_in()
 
 
@@ -261,18 +275,11 @@ def test_port(app_version):
     assert client.app.version == app_version
 
 
-def test_response_none(client):
-    response = MagicMock(spec_set=Response)
-
-    assert client._cast(response, None) == response
-    assert client._cast(response, response_class=None) == response
-
-
 def test_response_str(client):
     response = MagicMock(spec_set=Response)
 
     type(response).text = PropertyMock(return_value="text response")
-    assert client._cast(response, six.text_type) == "text response"
+    assert client._cast(response, str) == "text response"
 
     type(response).text = PropertyMock(return_value="text response")
     with pytest.raises(exceptions.APIError, match="Exception during response parsing."):
@@ -342,17 +349,19 @@ def test_response_unsupported(client):
 
     type(response).text = PropertyMock(return_value="123.01")
     with pytest.raises(
-        exceptions.APIError, match="No handler defined to cast response."
+        exceptions.APIError,
+        match="No handler defined to cast response.",
     ):
         client._cast(response, float)
 
     with pytest.raises(
-        exceptions.APIError, match="No handler defined to cast response."
+        exceptions.APIError,
+        match="No handler defined to cast response.",
     ):
         client._get(_name=APINames.Application, _method="version", response_class=float)
 
 
-def test_simple_response(client, orig_torrent):
+def test_simple_response(client):
     torrent = client.torrents_info()[0]
     assert isinstance(torrent, TorrentDictionary)
     torrent = client.torrents_info(SIMPLE_RESPONSE=True)[0]
@@ -373,7 +382,8 @@ def test_simple_response(client, orig_torrent):
 
 def test_request_extra_headers():
     client = Client(
-        VERIFY_WEBUI_CERTIFICATE=False, EXTRA_HEADERS={"X-MY-HEADER": "asdf"}
+        VERIFY_WEBUI_CERTIFICATE=False,
+        EXTRA_HEADERS={"X-MY-HEADER": "asdf"},
     )
     client.auth.log_in()
 
@@ -381,7 +391,9 @@ def test_request_extra_headers():
     assert r.request.headers["X-MY-HEADER"] == "asdf"
 
     r = client._get(
-        APINames.Application, "version", headers={"X-MY-HEADER-TWO": "zxcv"}
+        APINames.Application,
+        "version",
+        headers={"X-MY-HEADER-TWO": "zxcv"},
     )
     assert r.request.headers["X-MY-HEADER"] == "asdf"
     assert r.request.headers["X-MY-HEADER-TWO"] == "zxcv"
@@ -408,11 +420,8 @@ def test_request_extra_headers():
     assert r.request.headers["X-MY-HEADER"] == "zxcv"
 
 
+@pytest.mark.skipif_before_api_version("2.2.1")
 def test_requests_timeout(api_version):
-    # timeouts are weird on python 2...just skip it...
-    if sys.version_info[0] < 3 or v(api_version) < v("2.2.1"):
-        return
-
     class MyTimeoutError(Exception):
         pass
 
@@ -441,37 +450,41 @@ def test_requests_timeout(api_version):
                 raise MyTimeoutError
 
 
-def test_request_extra_params(client, orig_torrent_hash):
-    """extra params can be sent directly to qBittorrent but there aren't any
-    real use-cases so force it."""
-    json_response = client._post(
-        APINames.Torrents, "info", hashes=orig_torrent_hash
-    ).json()
-    torrent = TorrentInfoList(json_response, client)[0]
-    assert isinstance(torrent, TorrentDictionary)
-    json_response = client._get(
-        APINames.Torrents, "info", hashes=orig_torrent_hash
-    ).json()
-    torrent = TorrentInfoList(json_response, client)[0]
-    assert isinstance(torrent, TorrentDictionary)
+def test_request_extra_params(client, orig_torrent):
+    """Extra params can be sent directly to qBittorrent but there aren't any real use-
+    cases so force it."""
+    response = client._post(
+        APINames.Torrents,
+        "info",
+        hashes=orig_torrent.hash,
+        extra_param="extra",
+    )
+    assert "extra_param=extra" in response.request.body
+    torrent = TorrentInfoList(response.json(), client)[0]
+    assert torrent.hash == orig_torrent.hash
+
+    response = client._get(
+        APINames.Torrents,
+        "info",
+        hashes=orig_torrent.hash,
+        extra_param="extra",
+    )
+    assert "extra_param=extra" in response.request.url
+    torrent = TorrentInfoList(response.json(), client)[0]
+    assert torrent.hash == orig_torrent.hash
 
 
-def test_mock_api_version():
-    client = Client(MOCK_WEB_API_VERSION="1.5", VERIFY_WEBUI_CERTIFICATE=False)
-    assert client.app_web_api_version() == "1.5"
-
-
-def test_unsupported_version_error():
+def test_unsupported_version_error(monkeypatch):
     if IS_QBT_DEV:
         return
 
     client = Client(
-        MOCK_WEB_API_VERSION="0.0.0",
         VERIFY_WEBUI_CERTIFICATE=False,
         RAISE_ERROR_FOR_UNSUPPORTED_QBITTORRENT_VERSIONS=True,
     )
+    monkeypatch.setattr(client, "app_version", MagicMock(return_value="1.0.0"))
     with pytest.raises(exceptions.UnsupportedQbittorrentVersion):
-        client.app_version()
+        client.app_web_api_version()
 
     client = Client(
         VERIFY_WEBUI_CERTIFICATE=False,
@@ -504,9 +517,9 @@ def test_verify_cert(app_version):
     assert client.app.version == app_version
 
     # this is only ever going to work with a trusted cert....disabling for now
-    # client = Client(VERIFY_WEBUI_CERTIFICATE=True)  # noqa: E800
-    # assert client._VERIFY_WEBUI_CERTIFICATE is True  # noqa: E800
-    # assert client.app.version == app_version  # noqa: E800
+    # client = Client(VERIFY_WEBUI_CERTIFICATE=True)
+    # assert client._VERIFY_WEBUI_CERTIFICATE is True
+    # assert client.app.version == app_version
 
     environ["QBITTORRENTAPI_DO_NOT_VERIFY_WEBUI_CERTIFICATE"] = "true"
     client = Client(VERIFY_WEBUI_CERTIFICATE=True)
@@ -529,14 +542,16 @@ def test_api_connection_error():
         Client(host="localhost:8081").auth_log_in(_retries=3)
 
 
-def test_http400(client, app_version, orig_torrent_hash):
+def test_http400(client, app_version, orig_torrent):
     with pytest.raises(exceptions.MissingRequiredParameters400Error):
-        client.torrents_file_priority(hash=orig_torrent_hash)
+        client.torrents_file_priority(torrent_hash=orig_torrent.hash)
 
     if v(app_version) >= v("4.1.6"):
         with pytest.raises(exceptions.InvalidRequest400Error) as exc_info:
             client.torrents_file_priority(
-                hash=orig_torrent_hash, file_ids="asdf", priority="asdf"
+                torrent_hash=orig_torrent.hash,
+                file_ids="asdf",
+                priority="asdf",
             )
         assert exc_info.value.http_status_code == 400
 
@@ -557,30 +572,34 @@ def test_http401():
 @pytest.mark.parametrize("params", ({}, {"hash": "asdf"}, {"hashes": "asdf|asdf"}))
 def test_http404(client, params):
     with pytest.raises(exceptions.NotFound404Error, match="Torrent hash") as exc_info:
-        client.torrents_rename(hash="zxcv", new_torrent_name="erty")
+        client.torrents_rename(torrent_hash="zxcv", new_torrent_name="erty")
     assert "zxcv" in exc_info.value.args[0]
 
-    response = MagicMock(spec=Response, status_code=404, text="")
-    with pytest.raises(exceptions.HTTPError, match="") as exc_info:
+    response = MagicMock(spec=Response, status_code=404, text="", request=object())
+    with pytest.raises(exceptions.HTTPError) as exc_info:
         Request._handle_error_responses(data={}, params=params, response=response)
     assert exc_info.value.http_status_code == 404
     if params:
         assert params[list(params.keys())[0]] in exc_info.value.args[0]
 
-    response = MagicMock(spec=Response, status_code=404, text="unexpected msg")
+    response = MagicMock(
+        spec=Response, status_code=404, text="unexpected msg", request=object()
+    )
     with pytest.raises(exceptions.HTTPError, match="unexpected msg") as exc_info:
         Request._handle_error_responses(data={}, params=params, response=response)
     assert exc_info.value.http_status_code == 404
     assert exc_info.value.args[0] == "unexpected msg"
 
-    response = MagicMock(spec=Response, status_code=404, text="")
-    with pytest.raises(exceptions.HTTPError, match="") as exc_info:
+    response = MagicMock(spec=Response, status_code=404, text="", request=object())
+    with pytest.raises(exceptions.HTTPError) as exc_info:
         Request._handle_error_responses(data=params, params={}, response=response)
     assert exc_info.value.http_status_code == 404
     if params:
         assert params[list(params.keys())[0]] in exc_info.value.args[0]
 
-    response = MagicMock(spec=Response, status_code=404, text="unexpected msg")
+    response = MagicMock(
+        spec=Response, status_code=404, text="unexpected msg", request=object()
+    )
     with pytest.raises(exceptions.HTTPError, match="unexpected msg") as exc_info:
         Request._handle_error_responses(data=params, params={}, response=response)
     assert exc_info.value.http_status_code == 404
@@ -610,7 +629,9 @@ def test_http415(client):
 
 @pytest.mark.parametrize("status_code", (500, 503))
 def test_http500(status_code):
-    response = MagicMock(spec=Response, status_code=status_code, text="asdf")
+    response = MagicMock(
+        spec=Response, status_code=status_code, text="asdf", request=object()
+    )
     with pytest.raises(exceptions.InternalServerError500Error) as exc_info:
         Request._handle_error_responses(data={}, params={}, response=response)
     assert exc_info.value.http_status_code == status_code
@@ -618,7 +639,9 @@ def test_http500(status_code):
 
 @pytest.mark.parametrize("status_code", (402, 406))
 def test_http_error(status_code):
-    response = MagicMock(spec=Response, status_code=status_code, text="asdf")
+    response = MagicMock(
+        spec=Response, status_code=status_code, text="asdf", request=object()
+    )
     with pytest.raises(exceptions.HTTPError) as exc_info:
         Request._handle_error_responses(data={}, params={}, response=response)
     assert exc_info.value.http_status_code == status_code
@@ -632,31 +655,108 @@ def test_request_retry_success(monkeypatch, caplog):
     client.auth_log_in()
     with monkeypatch.context() as m:
         m.setattr(client, "_request", request500)
-        with caplog.at_level(logging.DEBUG, logger="qbittorrentapi"):
-            with pytest.raises(exceptions.HTTP500Error):
-                client.app_version()
+        with (
+            caplog.at_level(logging.DEBUG, logger="qbittorrentapi"),
+            pytest.raises(exceptions.HTTP500Error),
+        ):
+            client.app_version()
         assert "Retry attempt" in caplog.text
 
 
 def test_request_retry_skip(caplog):
     client = Client(VERIFY_WEBUI_CERTIFICATE=False)
     client.auth_log_in()
-    with caplog.at_level(logging.DEBUG, logger="qbittorrentapi"):
-        with pytest.raises(exceptions.MissingRequiredParameters400Error):
-            client.torrents_rename()
+    with (
+        caplog.at_level(logging.DEBUG, logger="qbittorrentapi"),
+        pytest.raises(exceptions.MissingRequiredParameters400Error),
+    ):
+        client.torrents_rename()
     assert "Retry attempt" not in caplog.text
 
 
 def test_verbose_logging(caplog):
     client = Client(VERBOSE_RESPONSE_LOGGING=True, VERIFY_WEBUI_CERTIFICATE=False)
-    with caplog.at_level(logging.DEBUG, logger="qbittorrentapi"):
-        with pytest.raises(exceptions.NotFound404Error):
-            client.torrents_rename(hash="asdf", new_torrent_name="erty")
+    with (
+        caplog.at_level(logging.DEBUG, logger="qbittorrentapi"),
+        pytest.raises(exceptions.NotFound404Error),
+    ):
+        client.torrents_rename(torrent_hash="asdf", new_torrent_name="erty")
     assert "Response status" in caplog.text
 
 
 def test_stack_printing(capsys):
-    client = Client(PRINT_STACK_FOR_EACH_REQUEST=True, VERIFY_WEBUI_CERTIFICATE=False)
+    client = Client(VERIFY_WEBUI_CERTIFICATE=False)
+    client._PRINT_STACK_FOR_EACH_REQUEST = True
     client.app_version()
-    captured = capsys.readouterr()
-    assert "print_stack()" in captured.err
+
+    assert "print_stack()" in capsys.readouterr().err
+
+
+def test_auto_authentication(caplog, app_version):
+    client = Client(
+        RAISE_NOTIMPLEMENTEDERROR_FOR_UNIMPLEMENTED_API_ENDPOINTS=True,
+        VERIFY_WEBUI_CERTIFICATE=False,
+    )
+    # check if first API call works if already logged in
+    client.auth_log_in()
+    with caplog.at_level(logging.DEBUG, logger="qbittorrentapi"):
+        qbt_version = client.app.version
+    assert "Login may have expired...attempting new login" not in caplog.text
+    assert qbt_version == app_version
+
+    # ensure login happens after first API call fails
+    client.auth_log_out()
+    with caplog.at_level(logging.DEBUG, logger="qbittorrentapi"):
+        qbt_version = client.app.version
+    assert "Login may have expired...attempting new login" in caplog.text
+    assert qbt_version == app_version
+
+
+def test_not_implemented_no_error(monkeypatch):
+    client = Client(VERIFY_WEBUI_CERTIFICATE=False)
+
+    monkeypatch.setattr(client, "app_web_api_version", MagicMock(return_value="1.0.0"))
+    assert client.search_categories() is None
+
+    monkeypatch.setattr(client, "app_web_api_version", MagicMock(return_value="10.0.0"))
+    assert client.search_categories() is None
+
+
+def test_not_implemented_error(monkeypatch, client):
+    monkeypatch.setattr(client, "app_web_api_version", MagicMock(return_value="1.0.0"))
+    with pytest.raises(NotImplementedError, match=r"This endpoint is available"):
+        client.search_categories()
+
+    monkeypatch.setattr(client, "app_web_api_version", MagicMock(return_value="10.0.0"))
+    with pytest.raises(NotImplementedError, match=r"This endpoint was removed"):
+        client.search_categories()
+
+
+def test_http_adapter_defaults():
+    client = Client(
+        RAISE_NOTIMPLEMENTEDERROR_FOR_UNIMPLEMENTED_API_ENDPOINTS=True,
+        VERIFY_WEBUI_CERTIFICATE=False,
+    )
+    assert client._session.adapters["http://"] is client._session.adapters["https://"]
+    assert client._session.adapters["http://"].max_retries.total == 1
+    assert client._session.adapters["http://"]._pool_connections == DEFAULT_POOLSIZE
+    assert client._session.adapters["http://"]._pool_maxsize == DEFAULT_POOLSIZE
+    assert client._session.adapters["http://"]._pool_block is DEFAULT_POOLBLOCK
+
+
+def test_http_adapter_overrides():
+    client = Client(
+        RAISE_NOTIMPLEMENTEDERROR_FOR_UNIMPLEMENTED_API_ENDPOINTS=True,
+        VERIFY_WEBUI_CERTIFICATE=False,
+        HTTPADAPTER_ARGS=dict(
+            pool_connections=100,
+            pool_maxsize=50,
+            max_retries=10,
+            pool_block=True,
+        ),
+    )
+    assert client._session.adapters["http://"] is client._session.adapters["https://"]
+    assert client._session.adapters["http://"].max_retries.total == 10
+    assert client._session.adapters["http://"]._pool_connections == 100
+    assert client._session.adapters["http://"]._pool_maxsize == 50
+    assert client._session.adapters["http://"]._pool_block is True
